
from django.apps import apps
from django.shortcuts import get_object_or_404, render
from django.contrib.auth.views import redirect_to_login

from flatpages.models import FlatPage


def flatpage(request, url):

    obj = get_object_or_404(FlatPage, url=url)

    if obj.registration_required and not request.user.is_authenticated():
        return redirect_to_login(request.path)

    config = apps.get_app_config('flatpages')

    template_name = obj.template_name or config.default_template

    return render(request, template_name, {'flatpage': obj})




from django.apps import apps
from django.utils.module_loading import import_string


def get_wising_editor(editor_name):

    if not editor_name:
        return None

    config = apps.get_app_config('flatpages')
    
    try:
        return import_string(config.wising_editors[editor_name])
    except ImportError:
        raise Exception('Flatpage editor module is undefined')
    except KeyError:
        raise Exception('Unknown flatpage editor module')




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

from flatpages.constants import FLATPAGE_EDITORS


class DefaultFlatPagesConfig(AppConfig):

    name = 'flatpages'
    verbose_name = _("Flat Pages")

    wising_editor = None
    wising_editors = FLATPAGE_EDITORS

    default_template = 'flatpages/default.html'


default_app_config = 'flatpages.DefaultFlatPagesConfig'
